from __future__ import annotations

import argparse
import logging
import sys

from biliass import Danmaku2ASS
from biliass import __version__ as biliass_version


def main():
    logging.basicConfig(format="%(levelname)s: %(message)s")
    if len(sys.argv) == 1:
        sys.argv.append("--help")
    parser = argparse.ArgumentParser(description="bilibili ASS Danmaku converter", prog="biliass")
    parser.add_argument("-v", "--version", action="version", version="%(prog)s {}".format(biliass_version))
    parser.add_argument("-o", "--output", metavar="OUTPUT", help="Output file")
    parser.add_argument("-s", "--size", metavar="WIDTHxHEIGHT", required=True, help="Stage size in pixels")
    parser.add_argument(
        "-fn",
        "--font",
        metavar="FONT",
        help="Specify font face [default: %s]" % "sans-serif",
        default="sans-serif",
    )
    parser.add_argument(
        "-fs",
        "--fontsize",
        metavar="SIZE",
        help=("Default font size [default: %s]" % 25),
        type=float,
        default=25.0,
    )
    parser.add_argument("-a", "--alpha", metavar="ALPHA", help="Text opacity", type=float, default=1.0)
    parser.add_argument(
        "-dm",
        "--duration-marquee",
        metavar="SECONDS",
        help="Duration of scrolling comment display [default: %s]" % 5,
        type=float,
        default=5.0,
    )
    parser.add_argument(
        "-ds",
        "--duration-still",
        metavar="SECONDS",
        help="Duration of still comment display [default: %s]" % 5,
        type=float,
        default=5.0,
    )
    parser.add_argument("-fl", "--filter", help="Regular expression to filter comments")
    parser.add_argument(
        "-flf", "--filter-file", help="Regular expressions from file (one line one regex) to filter comments"
    )
    parser.add_argument(
        "-p", "--protect", metavar="HEIGHT", help="Reserve blank on the bottom of the stage", type=int, default=0
    )
    parser.add_argument("-r", "--reduce", action="store_true", help="Reduce the amount of comments if stage is full")
    parser.add_argument("-f", "--format", choices=["xml", "protobuf"], default="xml", help="Input danmaku format (xml or protobuf)")
    parser.add_argument("file", metavar="FILE", nargs="+", help="Comment file to be processed")
    args = parser.parse_args()
    try:
        width, height = str(args.size).split("x", 1)
        width = int(width)
        height = int(height)
    except ValueError:
        raise ValueError("Invalid stage size: %r" % args.size)

    inputs = []
    for file in args.file:
        try:
            with open(file, "r" if args.format == "xml" else "rb") as f:
                inputs.append(f.read())
        except UnicodeDecodeError:
            logging.error(f"Failed to decode file {file}, if it is a protobuf file, please use `-f protobuf`")
            sys.exit(1)

    if args.output:
        fo = open(args.output, "w", encoding="utf-8-sig", errors="replace", newline="\r\n")
    else:
        fo = sys.stdout
    output = Danmaku2ASS(
        inputs,
        width,
        height,
        args.format,
        args.protect,
        args.font,
        args.fontsize,
        args.alpha,
        args.duration_marquee,
        args.duration_still,
        args.filter,
        args.reduce,
    )
    fo.write(output)
    fo.close()


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/danmaku.proto
"""Generated protocol buffer code."""
from __future__ import annotations

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16protobuf/danmaku.proto"\xba\x01\n\x0b\x44\x61nmakuElem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08progress\x18\x02 \x01(\x05\x12\x0c\n\x04mode\x18\x03 \x01(\x05\x12\x10\n\x08\x66ontsize\x18\x04 \x01(\x05\x12\r\n\x05\x63olor\x18\x05 \x01(\r\x12\x10\n\x08mid_hash\x18\x06 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t\x12\r\n\x05\x63time\x18\x08 \x01(\x03\x12\x0e\n\x06\x61\x63tion\x18\t \x01(\t\x12\x0c\n\x04pool\x18\n \x01(\x05\x12\x0e\n\x06id_str\x18\x0b \x01(\t"+\n\x0c\x44\x61nmakuEvent\x12\x1b\n\x05\x65lems\x18\x01 \x03(\x0b\x32\x0c.DanmakuElemb\x06proto3'
)


_DANMAKUELEM = DESCRIPTOR.message_types_by_name["DanmakuElem"]
_DANMAKUEVENT = DESCRIPTOR.message_types_by_name["DanmakuEvent"]
DanmakuElem = _reflection.GeneratedProtocolMessageType(
    "DanmakuElem",
    (_message.Message,),
    {
        "DESCRIPTOR": _DANMAKUELEM,
        "__module__": "protobuf.danmaku_pb2"
        # @@protoc_insertion_point(class_scope:DanmakuElem)
    },
)
_sym_db.RegisterMessage(DanmakuElem)

DanmakuEvent = _reflection.GeneratedProtocolMessageType(
    "DanmakuEvent",
    (_message.Message,),
    {
        "DESCRIPTOR": _DANMAKUEVENT,
        "__module__": "protobuf.danmaku_pb2"
        # @@protoc_insertion_point(class_scope:DanmakuEvent)
    },
)
_sym_db.RegisterMessage(DanmakuEvent)

if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    _DANMAKUELEM._serialized_start = 27
    _DANMAKUELEM._serialized_end = 213
    _DANMAKUEVENT._serialized_start = 215
    _DANMAKUEVENT._serialized_end = 258
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['biliass', 'biliass.protobuf']

package_data = \
{'': ['*']}

install_requires = \
['protobuf>=4.21.9,<5.0.0']

entry_points = \
{'console_scripts': ['biliass = biliass.__main__:main']}

setup_kwargs = {
    'name': 'biliass',
    'version': '1.3.7',
    'description': '将 B 站 XML 弹幕转换为 ASS 弹幕',
    'long_description': '# biliass\n\n<p align="center">\n   <a href="https://python.org/" target="_blank"><img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/biliass?logo=python&style=flat-square"></a>\n   <a href="https://pypi.org/project/biliass/" target="_blank"><img src="https://img.shields.io/pypi/v/biliass?style=flat-square" alt="pypi"></a>\n   <a href="https://pypi.org/project/biliass/" target="_blank"><img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/biliass?style=flat-square"></a>\n   <a href="https://actions-badge.atrox.dev/yutto-dev/biliass/goto?ref=main"><img alt="Build Status" src="https://img.shields.io/endpoint.svg?url=https%3A%2F%2Factions-badge.atrox.dev%2Fyutto-dev%2Fbiliass%2Fbadge%3Fref%3Dmain&style=flat-square&label=Test" /></a>\n   <a href="LICENSE"><img alt="LICENSE" src="https://img.shields.io/github/license/yutto-dev/biliass?style=flat-square"></a>\n   <a href="https://gitmoji.dev"><img src="https://img.shields.io/badge/gitmoji-%20😜%20😍-FFDD67?style=flat-square" alt="Gitmoji"></a>\n</p>\n\nbiliass，只是 Danmaku2ASS 的 bilili 与 yutto 适配版\n\n原版：<https://github.com/m13253/danmaku2ass>\n\n仅支持 bilibili 弹幕，支持 XML 弹幕和 Protobuf 弹幕\n\n## Install\n\n```bash\npip install biliass\n```\n\n## Usage\n\n```bash\n# XML 弹幕\nbiliass danmaku.xml -s 1920x1080 -o danmaku.ass\n# protobuf 弹幕\nbiliass danmaku.pb -s 1920x1080 -f protobuf -o danmaku.ass\n```\n\n```python\nfrom biliass import Danmaku2ASS\n\n# xml\nDanmaku2ASS(\n    xml_text_or_bytes,\n    width,\n    height,\n    input_format="xml",\n    reserve_blank=0,\n    font_face="sans-serif",\n    font_size=width / 40,\n    text_opacity=0.8,\n    duration_marquee=15.0,\n    duration_still=10.0,\n    comment_filter=None,\n    is_reduce_comments=False,\n    progress_callback=None,\n)\n\n# protobuf\nDanmaku2ASS(\n    protobuf_bytes, # only bytes\n    width,\n    height,\n    input_format="protobuf",\n    reserve_blank=0,\n    font_face="sans-serif",\n    font_size=width / 40,\n    text_opacity=0.8,\n    duration_marquee=15.0,\n    duration_still=10.0,\n    comment_filter=None,\n    is_reduce_comments=False,\n    progress_callback=None,\n)\n```\n\n## TODO\n\n- 导出 bilibili 网页上的弹幕设置，并导入到 biliass\n',
    'author': 'm13253',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/yutto-dev/biliass',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
